==> wevue-1.2.28.tgz: package/lib/wxss.js <==
var css = require('css');

/*calc( 40 * ( ( 100vw - 0px ) / 750 ) )
-webkit-calc
-moz-calc(
*/

function clone(a) {
    return JSON.parse(JSON.stringify(a));
}

module.exports = function(wxss) {
    if (!wxss){
      return "";
    }
    var options = null;
    var result = {
        type: 'stylesheet',
        stylesheet: {
            rules: [],
            parsingErrors: []
        }
    };

    var obj = css.parse(wxss, options);

    if (obj && obj.stylesheet && obj.stylesheet.rules) {
        for (var i = 0; i < obj.stylesheet.rules.length; i++) {
            var rule = obj.stylesheet.rules[i];

            var declarations = [];
            if (!rule.declarations){
              continue;
            }
            for (var j = 0; j < rule.declarations.length; j++) {
                var item = rule.declarations[j];
                var rpxMatches = item.value.match(/\d+rpx/);
                if (rpxMatches) {

                    var declaration = clone(item);
                    for (var k = 0; k < rpxMatches.length; k++) {
                        var rpx = rpxMatches[k].match(/(\d+)rpx/);
                        declaration.value = declaration.value.replace(rpx[0], 'calc( ' + rpx[1] + ' * ( ( 100vw - 0px ) / 750 ) )');
                    }
                    declarations.push(declaration);

                    declaration = clone(item);
                    for (var k = 0; k < rpxMatches.length; k++) {
                        var rpx = rpxMatches[k].match(/(\d+)rpx/);
                        declaration.value = declaration.value.replace(rpx[0], '-webkit-calc( ' + rpx[1] + ' * ( ( 100vw - 0px ) / 750 ) )');
                    }
                    declarations.push(declaration);

                    declaration = clone(item);
                    for (var k = 0; k < rpxMatches.length; k++) {
                        var rpx = rpxMatches[k].match(/(\d+)rpx/);
                        declaration.value = declaration.value.replace(rpx[0], '-moz-calc( ' + rpx[1] + ' * ( ( 100vw - 0px ) / 750 ) )');
                    }
                    declarations.push(declaration);

                } else {
                    declarations.push(item);
                }
            }

            rule.declarations = declarations;
            result.stylesheet.rules.push(rule);
        }
    }
    return css.stringify(result, options);
}

==> wevue-2.1.4.tgz: package/lib/wxss.js <==
var css = require('css');

/*calc( 40 * ( ( 100vw - 0px ) / 750 ) )
-webkit-calc
-moz-calc(
*/

function clone(a) {
    return JSON.parse(JSON.stringify(a));
}

module.exports = function(wxss) {
    if (!wxss) {
        return "";
    }

    wxss  = wxss.replace(/\/\*[\s\S]*?\*\//g, "");

    var options = null;
    var result = {
        type: 'stylesheet',
        stylesheet: {
            rules: [],
            parsingErrors: []
        }
    };

    var obj = css.parse(wxss, options);

    if (obj && obj.stylesheet && obj.stylesheet.rules) {
        for (var i = 0; i < obj.stylesheet.rules.length; i++) {
            var rule = obj.stylesheet.rules[i];

            var declarations = [];
            if (!rule.declarations) {
                continue;
            }
            for (var j = 0; j < rule.declarations.length; j++) {
                var item = rule.declarations[j];
                var rpxMatches = item.value.match(/-?\d+rpx/);
                if (rpxMatches) {

                    var declaration = clone(item);
                    for (var k = 0; k < rpxMatches.length; k++) {
                        var rpx = rpxMatches[k].match(/(-?\d+)rpx/);
                        declaration.value = declaration.value.replace(rpx[0], 'calc( ' + rpx[1] + ' * ( ( 100vw - 0px ) / 750 ) )');
                    }
                    declarations.push(declaration);

                    declaration = clone(item);
                    for (var k = 0; k < rpxMatches.length; k++) {
                        var rpx = rpxMatches[k].match(/(-?\d+)rpx/);
                        declaration.value = declaration.value.replace(rpx[0], '-webkit-calc( ' + rpx[1] + ' * ( ( 100vw - 0px ) / 750 ) )');
                    }
                    declarations.push(declaration);

                    declaration = clone(item);
                    for (var k = 0; k < rpxMatches.length; k++) {
                        var rpx = rpxMatches[k].match(/(-?\d+)rpx/);
                        declaration.value = declaration.value.replace(rpx[0], '-moz-calc( ' + rpx[1] + ' * ( ( 100vw - 0px ) / 750 ) )');
                    }
                    declarations.push(declaration);

                } else {
                    declarations.push(item);
                }
            }

            rule.declarations = declarations;
            result.stylesheet.rules.push(rule);
        }
    }
    return css.stringify(result, options);
}
